==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/Input/gme/translations/gme_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="38"/>
        <source>GME Plugin</source>
        <translation>GME プラグイン</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="41"/>
        <source>Game Music Files</source>
        <translation>ゲーム音楽ファイル</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="103"/>
        <source>About GME Audio Plugin</source>
        <translation>GME 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="104"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>QMMP 用 GME 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="105"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>このプラグインは Game_Music_Emu ライブラリを用いてゲーム音楽ファイルを再生します。</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="106"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>GMP プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>フェイドアウト時間幅:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>ミリ秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>フェイドアウトさせる</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Input/gme/translations/gme_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="50"/>
        <source>GME Plugin</source>
        <translation>GME プラグイン</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="53"/>
        <source>Game Music Files</source>
        <translation>ゲーム音楽ファイル</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="117"/>
        <source>About GME Audio Plugin</source>
        <translation>GME 音響プラグインについて</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="118"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>QMMP 用 GME 音響プラグイン</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="119"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>このプラグインは Game_Music_Emu ライブラリを用いてゲーム音楽ファイルを再生します。</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="120"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>GMP プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>フェイドアウト時間幅:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>ミリ秒</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>フェイドアウトさせる</translation>
    </message>
</context>
</TS>
